<?php
/**
 * sixteen Theme Customizer
 *
 * @package sixteen
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function sixteen_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	
	
	//Basic Theme Settings
	$wp_customize->add_section( 'sixteen_basic_settings' , array(
	    'title'      => __( 'Basic Settings', 'sixteen' ),
	    'priority'   => 30,
	) );
	
	$wp_customize->add_setting( 'sixteen_favicon' , array(
	    'default'     => '',
	    'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sixteen_favicon',
	        array(
	            'label' => 'Upload Favicon',
	            'section' => 'sixteen_basic_settings',
	            'settings' => 'sixteen_favicon',
	            'priority' => 5,
	        )
		)
	);
	
	$wp_customize->add_setting( 'sixteen_apple_icon' , array(
	    'default'     => '',
	    'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sixteen_apple_icon',
	        array(
	            'label' => 'Upload Favicon',
	            'section' => 'sixteen_basic_settings',
	            'settings' => 'sixteen_apple_icon',
	            'priority' => 5,
	        )
		)
	);
	
	$wp_customize->add_setting( 'sixteen_disable_featimg' , array(
	    'default'     => false,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox',
	) );
	
	$wp_customize->add_control(	   
        'sixteen_disable_featimg',
        array(
            'label' => 'Disable Featured Images on Posts.',
            'description' => 'This will Remove the Featured Images from Showing up on Individual Posts, however, it will not remove it from homepage and other elements.',
            'section' => 'sixteen_basic_settings',
            'settings' => 'sixteen_disable_featimg',
            'priority' => 5,
            'type' => 'checkbox',
        )
	);
	
	$wp_customize->add_setting( 'sixteen_disable_nextprev' , array(
	    'default'     => true,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox',
	) );
	
	
	
	$wp_customize->add_control(	   
        'sixteen_disable_nextprev',
        array(
            'label' => 'Disable Next/Prev Posts on Single Posts.',
            'description' => 'This will Remove the the link to next and previous posts on all posts.',
            'section' => 'sixteen_basic_settings',
            'settings' => 'sixteen_disable_nextprev',
            'priority' => 5,
            'type' => 'checkbox',
        )
	);
	
	
	
	
	
	//Logo Settings
	$wp_customize->add_section( 'title_tagline' , array(
	    'title'      => __( 'Title, Tagline & Logo', 'sixteen' ),
	    'priority'   => 30,
	) );
	
	$wp_customize->add_setting( 'sixteen_logo' , array(
	    'default'     => '',
	    'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sixteen_logo',
	        array(
	            'label' => 'Upload Logo',
	            'section' => 'title_tagline',
	            'settings' => 'sixteen_logo',
	            'priority' => 5,
	        )
		)
	);
	
	$wp_customize->add_setting( 'sixteen_logo_resize' , array(
	    'default'     => 100,
	    'sanitize_callback' => 'sixteen_sanitize_positive_number',
	) );
	$wp_customize->add_control(
	        'sixteen_logo_resize',
	        array(
	            'label' => 'Resize & Adjust Logo',
	            'section' => 'title_tagline',
	            'settings' => 'sixteen_logo_resize',
	            'priority' => 6,
	            'type' => 'range',
	            'active_callback' => 'sixteen_logo_enabled',
	            'input_attrs' => array(
			        'min'   => 30,
			        'max'   => 200,
			        'step'  => 5,
			    ),
	        )
	);
	
	function sixteen_logo_enabled($control) {
		$option = $control->manager->get_setting('sixteen_logo');
		return $option->value() == true;
	}
	
	
	
	//Replace Header Text Color with, separate colors for Title and Description
	//Override sixteen_site_titlecolor
	$wp_customize->remove_control('display_header_text');
	$wp_customize->remove_setting('header_textcolor');
	$wp_customize->add_setting('sixteen_site_titlecolor', array(
	    'default'     => '#ffffff',
	    'sanitize_callback' => 'sanitize_hex_color',
	));
	
	$wp_customize->add_setting( 'sixteen_custombg' , array(
	    'default'     => false,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox'
	) );
	
	$wp_customize->add_control(
	'sixteen_custombg', array(
		'label' => __('Use a Custom Background Color or Image. Leave it unchecked to use Skin Defaults.','lens'),
		'description' => __('Refresh this page after saving the changes.','lens'),
		'section' => 'colors',
		'settings' => 'sixteen_custombg',
		'type' => 'checkbox'
		
	) );
	
	$wp_customize->add_control(new WP_Customize_Color_Control( 
		$wp_customize, 
		'sixteen_site_titlecolor', array(
			'label' => __('Site Title Color','sixteen'),
			'section' => 'colors',
			'settings' => 'sixteen_site_titlecolor',
			'type' => 'color'
		) ) 
	);
	
	$wp_customize->add_setting('sixteen_header_desccolor', array(
	    'default'     => '#ffffff',
	    'sanitize_callback' => 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control( 
		$wp_customize, 
		'sixteen_header_desccolor', array(
			'label' => __('Site Tagline Color','sixteen'),
			'section' => 'colors',
			'settings' => 'sixteen_header_desccolor',
			'type' => 'color'
		) ) 
	);
	
	//Settings for Nav Area
	$wp_customize->add_setting( 'sixteen_disable_nav_desc' , array(
	    'default'     => false,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox',
	) );
	
	$wp_customize->add_control(
	'sixteen_disable_nav_desc', array(
		'label' => __('Disable Description of Menu Items','sixteen'),
		'section' => 'nav',
		'settings' => 'sixteen_disable_nav_desc',
		'type' => 'checkbox'
	) );
	
	$wp_customize->add_setting( 'sixteen_disable_active_nav' , array(
	    'default'     => false,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox',
	) );
	
	$wp_customize->add_control(
	'sixteen_disable_active_nav', array(
		'label' => __('Disable Highlighting of Current Active Item on the Menu.','sixteen'),
		'section' => 'nav',
		'settings' => 'sixteen_disable_active_nav',
		'type' => 'checkbox'
	) );
	
	//Settings for Header Image
	$wp_customize->add_setting( 'sixteen_himg_style' , array(
	    'default'     => true,
	    'sanitize_callback' => 'sixteen_sanitize_himg_style'
	) );
	
	/* Sanitization Function */
	function sixteen_sanitize_himg_style( $input ) {
		if (in_array( $input, array('contain','cover') ) )
			return $input;
		else
			return '';	
	}
	
	$wp_customize->add_control(
	'sixteen_himg_style', array(
		'label' => __('Header Image Arrangement','sixteen'),
		'section' => 'header_image',
		'settings' => 'sixteen_himg_style',
		'type' => 'select',
		'choices' => array(
				'contain' => __('Contain','sixteen'),
				'cover' => __('Cover Completely','sixteen'),
				)
	) );
	
	$wp_customize->add_setting( 'sixteen_himg_align' , array(
	    'default'     => true,
	    'sanitize_callback' => 'sixteen_sanitize_himg_align'
	) );
	
	/* Sanitization Function */
	function sixteen_sanitize_himg_align( $input ) {
		if (in_array( $input, array('center','left','right') ) )
			return $input;
		else
			return '';	
	}
	
	$wp_customize->add_control(
	'sixteen_himg_align', array(
		'label' => __('Header Image Alignment','sixteen'),
		'section' => 'header_image',
		'settings' => 'sixteen_himg_align',
		'type' => 'select',
		'choices' => array(
				'center' => __('Center','sixteen'),
				'left' => __('Left','sixteen'),
				'right' => __('Right','sixteen'),
			)
		
	) );
	
	$wp_customize->add_setting( 'sixteen_himg_repeat' , array(
	    'default'     => true,
	    'sanitize_callback' => 'sixteen_sanitize_checkbox'
	) );
	
	$wp_customize->add_control(
	'sixteen_himg_repeat', array(
		'label' => __('Repeat Header Image','sixteen'),
		'section' => 'header_image',
		'settings' => 'sixteen_himg_repeat',
		'type' => 'checkbox',
	) );
	
	
	//Settings For Logo Area
	
	$wp_customize->add_setting(
		'sixteen_hide_title_tagline',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_hide_title_tagline', array(
		    'settings' => 'sixteen_hide_title_tagline',
		    'label'    => __( 'Hide Title and Tagline.', 'sixteen' ),
		    'section'  => 'title_tagline',
		    'type'     => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_branding_below_logo',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_branding_below_logo', array(
		    'settings' => 'sixteen_branding_below_logo',
		    'label'    => __( 'Display Site Title and Tagline Below the Logo.', 'sixteen' ),
		    'section'  => 'title_tagline',
		    'type'     => 'checkbox',
		    'active_callback' => 'sixteen_title_visible'
		)
	);
	
	function sixteen_title_visible( $control ) {
		$option = $control->manager->get_setting('sixteen_hide_title_tagline');
	    return $option->value() == false ;
	}
	
	$wp_customize->add_setting(
		'sixteen_center_logo',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_center_logo', array(
		    'settings' => 'sixteen_center_logo',
		    'label'    => __( 'Center Align.', 'sixteen' ),
		    'section'  => 'title_tagline',
		    'type'     => 'checkbox',
		)
	);
	
	
	
	// SLIDER PANEL
	$wp_customize->add_panel( 'sixteen_slider_panel', array(
	    'priority'       => 35,
	    'capability'     => 'edit_theme_options',
	    'theme_supports' => '',
	    'title'          => 'Main Slider',
	) );
	
	$wp_customize->add_section(
	    'sixteen_sec_slider_options',
	    array(
	        'title'     => 'Enable/Disable',
	        'priority'  => 0,
	        'panel'     => 'sixteen_slider_panel'
	    )
	);
	
	
	$wp_customize->add_setting(
		'sixteen_main_slider_enable',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_main_slider_enable', array(
		    'settings' => 'sixteen_main_slider_enable',
		    'label'    => __( 'Enable Slider on HomePage.', 'sixteen' ),
		    'section'  => 'sixteen_sec_slider_options',
		    'type'     => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_main_slider_enable_posts',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_main_slider_enable_posts', array(
		    'settings' => 'sixteen_main_slider_enable_posts',
		    'label'    => __( 'Enable Slider on All Posts.', 'sixteen' ),
		    'section'  => 'sixteen_sec_slider_options',
		    'type'     => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_main_slider_enable_pages',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_main_slider_enable_pages', array(
		    'settings' => 'sixteen_main_slider_enable_pages',
		    'label'    => __( 'Enable Slider on All Pages.', 'sixteen' ),
		    'section'  => 'sixteen_sec_slider_options',
		    'type'     => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_main_slider_count',
			array(
				'default' => '0',
				'sanitize_callback' => 'sixteen_sanitize_positive_number'
			)
	);
	
	// Select How Many Slides the User wants, and Reload the Page.
	$wp_customize->add_control(
			'sixteen_main_slider_count', array(
		    'settings' => 'sixteen_main_slider_count',
		    'label'    => __( 'No. of Slides(Min:0, Max: 10)' ,'sixteen'),
		    'section'  => 'sixteen_sec_slider_options',
		    'type'     => 'number',
		    'description' => __('Save the Settings, and Reload this page to Configure the Slides.','sixteen'),
		    
		)
	);
	
	
	//Slider Config
	$wp_customize->add_section(
	    'sixteen_slider_config',
	    array(
	        'title'     => __('Configure Slider','sixteen'),
	        'priority'  => 0,
	        'panel'     => 'sixteen_slider_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_pause',
			array(
				'default' => 5000,
				'sanitize_callback' => 'sixteen_sanitize_positive_number'
			)
	);
	
	$wp_customize->add_control(
			'sixteen_slider_pause', array(
		    'settings' => 'sixteen_slider_pause',
		    'label'    => __( 'Time Between Each Slide.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'number',
		    'description' => __('Value in Milliseconds. Default: 5000.','sixteen'),
		    
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_speed',
			array(
				'default' => 500,
				'sanitize_callback' => 'sixteen_sanitize_positive_number'
			)
	);
	
	$wp_customize->add_control(
			'sixteen_slider_speed', array(
		    'settings' => 'sixteen_slider_speed',
		    'label'    => __( 'Animation Speed.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'number',
		    'description' => __('Value in Milliseconds. Default: 500.','sixteen'),
		    
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_random',
			array(
				'default' => false,
				'sanitize_callback' => 'sixteen_sanitize_checkbox'
			)
	);
	
	$wp_customize->add_control(
			'sixteen_slider_random', array(
		    'settings' => 'sixteen_slider_random',
		    'label'    => __( 'Start Slider from Random Slide.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'checkbox',		    
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_pager',
			array(
				'default' => true,
				'sanitize_callback' => 'sixteen_sanitize_checkbox'
			)
	);
	
	$wp_customize->add_control(
			'sixteen_slider_pager', array(
		    'settings' => 'sixteen_slider_pager',
		    'label'    => __( 'Enable Pager.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'checkbox',
		    'description' => __('Pager is the Circles at the bottom, which represent current slide.','sixteen'),		    
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_autoplay',
			array(
				'default' => true, //Because, in nivo its Force Manual Transitions.
				'sanitize_callback' => 'sixteen_sanitize_checkbox'
			)
	);
	
	$wp_customize->add_control(
			'sixteen_slider_autoplay', array(
		    'settings' => 'sixteen_slider_autoplay',
		    'label'    => __( 'Enable Autoplay.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_slider_effect',
			array(
				'default' => 'random',
				'sanitize_callback' => 'sixteen_sanitize_text'
			)
	);
	
	$earray=array('random','sliceDown','sliceDownLeft','sliceUp','sliceUpLeft','sliceUpDown',
		'sliceUpDownLeft','fold','fade','slideInRight','slideInLeft','boxRandom','boxRain','boxRainReverse','boxRainGrow','boxRainGrowReverse');
		$earray = array_combine($earray, $earray);
	
	$wp_customize->add_control(
			'sixteen_slider_effect', array(
		    'settings' => 'sixteen_slider_effect',
		    'label'    => __( 'Slider Animation Effect.' ,'sixteen'),
		    'section'  => 'sixteen_slider_config',
		    'type'     => 'select',
		    'choices' => $earray,
	) );
	
	
	// Select How Many Slides the User wants, and Reload the Page.
	$wp_customize->add_control(
			'sixteen_main_slider_count', array(
		    'settings' => 'sixteen_main_slider_count',
		    'label'    => __( 'No. of Slides(Min:0, Max: 30)' ,'sixteen'),
		    'section'  => 'sixteen_sec_slider_options',
		    'type'     => 'number',
		    'description' => __('Save the Settings, and Reload this page to Configure the Slides.','sixteen'),
		    
		)
	);
		
	for ( $i = 1 ; $i <= 10 ; $i++ ) :
		
		//Create the settings Once, and Loop through it.
		static $x = 0;
		$wp_customize->add_section(
		    'sixteen_slide_sec'.$i,
		    array(
		        'title'     => 'Slide '.$i,
		        'priority'  => $i,
		        'panel'     => 'sixteen_slider_panel',
		        'active_callback' => 'sixteen_show_slide_sec'
		        
		    )
		);	
		
		$wp_customize->add_setting(
			'sixteen_slide_img'.$i,
			array( 'sanitize_callback' => 'esc_url_raw' )
		);
		
		$wp_customize->add_control(
		    new WP_Customize_Image_Control(
		        $wp_customize,
		        'sixteen_slide_img'.$i,
		        array(
		            'label' => '',
		            'section' => 'sixteen_slide_sec'.$i,
		            'settings' => 'sixteen_slide_img'.$i,			       
		        )
			)
		);
		
		$wp_customize->add_setting(
			'sixteen_slide_title'.$i,
			array( 'sanitize_callback' => 'sanitize_text_field' )
		);
		
		$wp_customize->add_control(
				'sixteen_slide_title'.$i, array(
			    'settings' => 'sixteen_slide_title'.$i,
			    'label'    => __( 'Slide Title','sixteen' ),
			    'section'  => 'sixteen_slide_sec'.$i,
			    'type'     => 'text',
			)
		);
		
		$wp_customize->add_setting(
			'sixteen_slide_desc'.$i,
			array( 'sanitize_callback' => 'sanitize_text_field' )
		);
		
		$wp_customize->add_control(
				'sixteen_slide_desc'.$i, array(
			    'settings' => 'sixteen_slide_desc'.$i,
			    'label'    => __( 'Slide Description','sixteen' ),
			    'section'  => 'sixteen_slide_sec'.$i,
			    'type'     => 'text',
			)
		);
		
		
		
		$wp_customize->add_setting(
			'sixteen_slide_CTA_button'.$i,
			array( 'sanitize_callback' => 'sanitize_text_field' )
		);
		
		$wp_customize->add_control(
				'sixteen_slide_CTA_button'.$i, array(
			    'settings' => 'sixteen_slide_CTA_button'.$i,
			    'label'    => __( 'Custom Call to Action Button Text(Optional)','sixteen' ),
			    'section'  => 'sixteen_slide_sec'.$i,
			    'type'     => 'text',
			)
		);
		
		$wp_customize->add_setting(
			'sixteen_slide_url'.$i,
			array( 'sanitize_callback' => 'esc_url_raw' )
		);
		
		$wp_customize->add_control(
				'sixteen_slide_url'.$i, array(
			    'settings' => 'sixteen_slide_url'.$i,
			    'label'    => __( 'Target URL','sixteen' ),
			    'section'  => 'sixteen_slide_sec'.$i,
			    'type'     => 'url',
			)
		);
		
	endfor;
	
	//active callback to see if the slide section is to be displayed or not
	function sixteen_show_slide_sec( $control ) {
	        $option = $control->manager->get_setting('sixteen_main_slider_count');
	        global $x;
	        if ( $x < $option->value() ){
	        	$x++;
	        	return true;
	        }
		}
	
	
	

	
	// CREATE THE FCA PANEL
	$wp_customize->add_panel( 'sixteen_fca_panel', array(
	    'priority'       => 40,
	    'capability'     => 'edit_theme_options',
	    'theme_supports' => '',
	    'title'          => 'Featured Content Areas',
	    'description'    => '',
	) );
	
	
	//SQUARE BOXES
	$wp_customize->add_section(
	    'sixteen_fc_boxes',
	    array(
	        'title'     => 'Square Boxes',
	        'priority'  => 10,
	        'panel'     => 'sixteen_fca_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_box_enable',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_box_enable', array(
		    'settings' => 'sixteen_box_enable',
		    'label'    => __( 'Enable Square Boxes & Posts Slider.', 'sixteen' ),
		    'section'  => 'sixteen_fc_boxes',
		    'type'     => 'checkbox',
		)
	);
	
 
	$wp_customize->add_setting(
		'sixteen_box_title',
		array( 'sanitize_callback' => 'sanitize_text_field' )
	);
	
	$wp_customize->add_control(
			'sixteen_box_title', array(
		    'settings' => 'sixteen_box_title',
		    'label'    => __( 'Title for the Boxes','sixteen' ),
		    'section'  => 'sixteen_fc_boxes',
		    'type'     => 'text',
		)
	);
 
 	$wp_customize->add_setting(
	    'sixteen_box_cat',
	    array( 'sanitize_callback' => 'sixteen_sanitize_category' )
	);
	
	$wp_customize->add_control(
	    new WP_Customize_Category_Control(
	        $wp_customize,
	        'sixteen_box_cat',
	        array(
	            'label'    => 'Category For Square Boxes.',
	            'settings' => 'sixteen_box_cat',
	            'section'  => 'sixteen_fc_boxes'
	        )
	    )
	);
	
		
	//SLIDER
	$wp_customize->add_section(
	    'sixteen_fc_slider',
	    array(
	        'title'     => __('Posts Slider','sixteen'),
	        'priority'  => 10,
	        'panel'     => 'sixteen_fca_panel',
	        'description' => 'This is the Posts Slider, displayed along with square boxes.',
	    )
	);
	
	
	$wp_customize->add_setting(
		'sixteen_slider_title',
		array( 'sanitize_callback' => 'sanitize_text_field' )
	);
	
	$wp_customize->add_control(
			'sixteen_slider_title', array(
		    'settings' => 'sixteen_slider_title',
		    'label'    => __( 'Title for the Slider', 'sixteen' ),
		    'section'  => 'sixteen_fc_slider',
		    'type'     => 'text',
		)
	);
	
	
	
/*
	// SETTING TO BE ADDED IN A FUTURE UPDATE.
	
	$wp_customize->add_setting(
		'slider_type'
		array( 'sanitize_callback' => 'sixteen_sanitize_slidertype' )
	);
	
	$wp_customize->add_control(
			'slider_type', array(
		    'settings' => 'slider_type',
		    'label'    => __( 'Choose Slider' ),
		    'section'  => 'fc_slider',
		    'type'     => 'select',
		    'choices'  => array(
		    				'3d' => '3D Slider',
		    				'bx' => 'BX Slider'),
		)
	);
*/
	
	$wp_customize->add_setting(
		'sixteen_slider_count',
		array( 'sanitize_callback' => 'sixteen_sanitize_positive_number' )
	);
	
	$wp_customize->add_control(
			'sixteen_slider_count', array(
		    'settings' => 'sixteen_slider_count',
		    'label'    => __( 'No. of Posts(Min:3, Max: 10)', 'sixteen' ),
		    'section'  => 'sixteen_fc_slider',
		    'type'     => 'range',
		    'input_attrs' => array(
		        'min'   => 3,
		        'max'   => 10,
		        'step'  => 1,
		        'class' => 'test-class test',
		        'style' => 'color: #0a0',
		    ),
		)
	);
		
	$wp_customize->add_setting(
		    'sixteen_slider_cat',
		    array( 'sanitize_callback' => 'sixteen_sanitize_category' )
		);
		
	$wp_customize->add_control(
	    new WP_Customize_Category_Control(
	        $wp_customize,
	        'sixteen_slider_cat',
	        array(
	            'label'    => __('Category For Slider.','sixteen'),
	            'settings' => 'sixteen_slider_cat',
	            'section'  => 'sixteen_fc_slider'
	        )
	    )
	);
	
	
	
	//IMAGE GRID
	
	$wp_customize->add_section(
	    'sixteen_fc_grid',
	    array(
	        'title'     => __('Image Grid','sixteen'),
	        'priority'  => 10,
	        'panel'     => 'sixteen_fca_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_grid_enable',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_grid_enable', array(
		    'settings' => 'sixteen_grid_enable',
		    'label'    => __( 'Enable Grid.', 'sixteen' ),
		    'section'  => 'sixteen_fc_grid',
		    'type'     => 'checkbox',
		)
	);
	
	
	$wp_customize->add_setting(
		'sixteen_grid_title',
		array( 'sanitize_callback' => 'sanitize_text_field' )
	);
	
	$wp_customize->add_control(
			'sixteen_grid_title', array(
		    'settings' => 'sixteen_grid_title',
		    'label'    => __( 'Title for the Grid', 'sixteen' ),
		    'section'  => 'sixteen_fc_grid',
		    'type'     => 'text',
		)
	);
	
	
	
	$wp_customize->add_setting(
		    'sixteen_grid_cat',
		    array( 'sanitize_callback' => 'sixteen_sanitize_category' )
		);
	
		
	$wp_customize->add_control(
	    new WP_Customize_Category_Control(
	        $wp_customize,
	        'sixteen_grid_cat',
	        array(
	            'label'    => __('Category For Image Grid','sixteen'),
	            'settings' => 'sixteen_grid_cat',
	            'section'  => 'sixteen_fc_grid'
	        )
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_grid_rows',
		array( 'sanitize_callback' => 'sixteen_sanitize_positive_number' )
	);
	
	$wp_customize->add_control(
			'sixteen_grid_rows', array(
		    'settings' => 'sixteen_grid_rows',
		    'label'    => __( 'Max No. of Posts in the Grid. Enter 0 to Disable the Grid.', 'sixteen' ),
		    'section'  => 'sixteen_fc_grid',
		    'type'     => 'number',
		    'default'  => '0'
		)
	);
	
	
	// Layout and Design
	$wp_customize->add_panel( 'sixteen_design_panel', array(
	    'priority'       => 40,
	    'capability'     => 'edit_theme_options',
	    'theme_supports' => '',
	    'title'          => __('Design & Layout','sixteen'),
	) );
	
	$wp_customize->add_section(
	    'sixteen_site_layout_sec',
	    array(
	        'title'     => __('Site Layout','sixteen'),
	        'priority'  => 0,
	        'panel'     => 'sixteen_design_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_site_layout',
		array( 'sanitize_callback' => 'sixteen_sanitize_site_layout' )
	);
	
	function sixteen_sanitize_site_layout( $input ) {
		if ( in_array($input, array('full','boxed') ) )
			return $input;
		else 
			return '';	
	}
	
	$wp_customize->add_control(
		'sixteen_site_layout',array(
				'label' => __('Select Layout','sixteen'),
				'settings' => 'sixteen_site_layout',
				'section'  => 'sixteen_site_layout_sec',
				'type' => 'select',
				'choices' => array(
						'full' => __('Full Width Layout','sixteen'),
						'boxed' => __('Boxed','sixteen'),
						
					)
			)
	);
	
	$wp_customize->add_section(
	    'sixteen_design_options',
	    array(
	        'title'     => __('Blog Layout','sixteen'),
	        'priority'  => 0,
	        'panel'     => 'sixteen_design_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_blog_title',
		array( 
			'sanitize_callback' => 'sanitize_text_field',
			'default'	=> __('Recent Posts','sixteen'),
		 )
	);
	
	$wp_customize->add_control(
		'sixteen_blog_title',array(
				'label' => __('Blog Title','sixteen'),
				'settings' => 'sixteen_blog_title',
				'section'  => 'sixteen_design_options',
				'type' => 'text',
				
			)
	);
	
	
	$wp_customize->add_setting(
		'sixteen_blog_layout',
		array( 'sanitize_callback' => 'sixteen_sanitize_blog_layout' )
	);
	
	function sixteen_sanitize_blog_layout( $input ) {
		if ( in_array($input, array('grid','grid_2_column','grid_3_column','grid_4_column','photos_1_column','photos_2_column','photos_3_column','box_4_column') ) )
			return $input;
		else 
			return '';	
	}
	
	$wp_customize->add_control(
		'sixteen_blog_layout',array(
				'label' => __('Select Layout','sixteen'),
				'settings' => 'sixteen_blog_layout',
				'section'  => 'sixteen_design_options',
				'type' => 'select',
				'choices' => array(
						'grid' => __('Basic Blog Layout','sixteen'),
						'grid_2_column' => __('Grid - 2 Column','sixteen'),
						'grid_3_column' => __('Grid - 3 Column','sixteen'),
						'grid_4_column' => __('Grid - 4 Column','sixteen'),
						'photos_1_column' => __('Photography - 1 Column','sixteen'),
						'photos_2_column' => __('Photography - 2 Column','sixteen'),
						'photos_3_column' => __('Photography - 3 Column','sixteen'),
						'box_4_column' => __('Box Layout - 4 Column','sixteen'),
					)
			)
	);
	
	$wp_customize->add_section(
	    'sixteen_sidebar_options',
	    array(
	        'title'     => __('Sidebar Layout','sixteen'),
	        'priority'  => 0,
	        'panel'     => 'sixteen_design_panel'
	    )
	);
	
	$wp_customize->add_setting(
		'sixteen_disable_sidebar',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_disable_sidebar', array(
		    'settings' => 'sixteen_disable_sidebar',
		    'label'    => __( 'Disable Sidebar Everywhere.','sixteen' ),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'checkbox',
		    'default'  => false
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_disable_sidebar_home',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_disable_sidebar_home', array(
		    'settings' => 'sixteen_disable_sidebar_home',
		    'label'    => __( 'Disable Sidebar on Home/Blog.','sixteen' ),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'checkbox',
		    'active_callback' => 'sixteen_show_sidebar_options',
		    'default'  => false
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_disable_sidebar_archive',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_disable_sidebar_archive', array(
		    'settings' => 'sixteen_disable_sidebar_archive',
		    'label'    => __( 'Disable Sidebar on Archive/Category/Tag Pages.','sixteen' ),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'checkbox',
		    'active_callback' => 'sixteen_show_sidebar_options',
		    'default'  => false
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_disable_sidebar_front',
		array( 'sanitize_callback' => 'sixteen_sanitize_checkbox' )
	);
	
	$wp_customize->add_control(
			'sixteen_disable_sidebar_front', array(
		    'settings' => 'sixteen_disable_sidebar_front',
		    'label'    => __( 'Disable Sidebar on Front Page.','sixteen' ),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'checkbox',
		    'active_callback' => 'sixteen_show_sidebar_options',
		    'default'  => false
		)
	);
	
	
	$wp_customize->add_setting(
		'sixteen_sidebar_width',
		array(
			'default' => 4,
		    'sanitize_callback' => 'sixteen_sanitize_positive_number' )
	);
	
	$wp_customize->add_control(
			'sixteen_sidebar_width', array(
		    'settings' => 'sixteen_sidebar_width',
		    'label'    => __( 'Sidebar Width','sixteen' ),
		    'description' => __('Min: 25%, Default: 33%, Max: 40%','sixteen'),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'range',
		    'active_callback' => 'sixteen_show_sidebar_options',
		    'input_attrs' => array(
		        'min'   => 3,
		        'max'   => 5,
		        'step'  => 1,
		        'class' => 'sidebar-width-range',
		        'style' => 'color: #0a0',
		    ),
		)
	);
	
	$wp_customize->add_setting(
		'sixteen_sidebar_loc',
		array(
			'default' => 'right',
		    'sanitize_callback' => 'sixteen_sanitize_sidebar_loc' )
	);
	
	$wp_customize->add_control(
			'sixteen_sidebar_loc', array(
		    'settings' => 'sixteen_sidebar_loc',
		    'label'    => __( 'Sidebar Location','sixteen' ),
		    'section'  => 'sixteen_sidebar_options',
		    'type'     => 'select',
		    'active_callback' => 'sixteen_show_sidebar_options',
		    'choices' => array(
		        'left'   => "Left",
		        'right'   => "Right",
		    ),
		)
	);
	
	/* sanitization */
	function sixteen_sanitize_sidebar_loc( $input ) {
		if (in_array($input, array('left','right') ) ) :
			return $input;
		else :
			return '';
		endif;		
	}
	
	/* Active Callback Function */
	function sixteen_show_sidebar_options($control) {
	   
	    $option = $control->manager->get_setting('sixteen_disable_sidebar');
	    return $option->value() == false ;
	    
	}
	
	class Sixteen_Custom_CSS_Control extends WP_Customize_Control {
	    public $type = 'textarea';
	 
	    public function render_content() {
	        ?>
	            <label>
	                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	                <textarea rows="8" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
	            </label>
	        <?php
	    }
	}
	
	$wp_customize-> add_section(
    'sixteen_custom_codes',
    array(
    	'title'			=> __('Custom CSS','sixteen'),
    	'description'	=> __('Enter your Custom CSS to Modify design.','sixteen'),
    	'priority'		=> 11,
    	'panel'			=> 'sixteen_design_panel'
    	)
    );
    
	$wp_customize->add_setting(
	'sixteen_custom_css',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sixteen_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
	    new Sixteen_Custom_CSS_Control(
	        $wp_customize,
	        'sixteen_custom_css',
	        array(
	            'section' => 'sixteen_custom_codes',
	            'settings' => 'sixteen_custom_css'
	        )
	    )
	);
	
	class Sixteen_Custom_JS_Control extends WP_Customize_Control {
	    public $type = 'textarea';
	 
	    public function render_content() {
	        ?>
	            <label>
	                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	                <textarea rows="8" style="width:100%;background: #222; color: #eee;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
	            </label>
	        <?php
	    }
	}
	
	$wp_customize-> add_section(
    'sixteen_custom_codes_js',
    array(
    	'title'			=> __('Custom JS','sixteen'),
    	'description'	=> __('Enter your Custom JS Code. It will be Included in Head of the Site. Do NOT Include &lt;script&gt; and &lt;/script&gt; tags.','sixteen'),
    	'priority'		=> 11,
    	'panel'			=> 'sixteen_design_panel'
    	)
    );
    
	$wp_customize->add_setting(
	'sixteen_custom_js',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sixteen_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
	    new Sixteen_Custom_JS_Control(
	        $wp_customize,
	        'sixteen_custom_js',
	        array(
	            'section' => 'sixteen_custom_codes_js',
	            'settings' => 'sixteen_custom_js'
	        )
	    )
	);
	
	function sixteen_sanitize_text( $input ) {
	    return wp_kses_post( force_balance_tags( $input ) );
	}
	
	$wp_customize-> add_section(
    'sixteen_custom_footer',
    array(
    	'title'			=> __('Footer Credit Link','sixteen'),
    	'description'	=> __('Enter your Own Copyright Text.','sixteen'),
    	'priority'		=> 11,
    	'panel'			=> 'sixteen_design_panel'
    	)
    );
    
	$wp_customize->add_setting(
	'sixteen_footer_text',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control(	 
	       'sixteen_footer_text',
	        array(
	            'section' => 'sixteen_custom_footer',
	            'settings' => 'sixteen_footer_text',
	            'type' => 'text'
	        )
	);
	
	$wp_customize->add_setting(
	'sixteen_link_remove',
	array(
		'default'		=> false,
		'sanitize_callback'	=> 'sixteen_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(	 
	       'sixteen_link_remove',
	        array(
	            'section' => 'sixteen_custom_footer',
	            'label' => __('Remove Footer Theme Credit Link.','sixteen'),
	            'settings' => 'sixteen_link_remove',
	            'type' => 'checkbox'
	        )
	);
	
	//Skin and Accent Section
	$wp_customize-> add_section(
    'sixteen_skin_sec',
    array(
    	'title'			=> __('Choose Skin','sixteen'),
    	'description'	=> __('Select from Dark or Light','sixteen'),
    	'priority'		=> 10,
    	'panel'			=> 'sixteen_design_panel'
    	)
    );
    
	$wp_customize->add_setting(
	'sixteen_skin',
	array(
		'default'		=> 'light',
		'sanitize_callback'	=> 'sanitize_skin_field'
		)
	);
	
	$wp_customize->add_control(	 
	       'sixteen_skin',
	        array(
	            'section' => 'sixteen_skin_sec',
	            'settings' => 'sixteen_skin',
	            'type' => 'select',
	            'choices' => array(
	            				'default' => __('Default','sixteen'),
	            				'redwhite' => __('Red & White','sixteen'),
	            				'redbluewhite' => __('Red, Blue & White','sixteen'),
	            				'bluewhite' => __('Blue & White','sixteen'),
	            				'cyanwhite' => __('Cyan & White','sixteen'),
	            				/* 'grayscale' => __('Grayscale','sixteen'), */
	            				'emerald' => __('Emerald','sixteen'),
	            				'claret' => __('Claret','sixteen'),
	            				)           				
	        )
	);	
	
	function sanitize_skin_field($input) {
		if ( in_array($input, array('default','dark','redwhite','redbluewhite','bluewhite','grayscale','emerald','claret','cyanwhite') ) )
			return $input;
		else 
			return '';	
	}
		
	
	$wp_customize->add_section(
	    'sixteen_typo_options',
	    array(
	        'title'     => __('Google Web Fonts','sixteen'),
	        'priority'  => 41,
	        'description' => __('Fonts are Sorted in Order of Popularity. Defaults: Roboto.','sixteen')
	    )
	);
	
	/**
	 * A class to create a dropdown for all google fonts
	 */
	 class Google_Font_Dropdown_Custom_Control extends WP_Customize_Control
	 {
	    private $fonts = false;
	
	    public function __construct($manager, $id, $args = array(), $options = array())
	    {
	        $this->fonts = $this->get_fonts();
	        parent::__construct( $manager, $id, $args );
	    }

	    /**
	     * Render the content of the category dropdown
	     *
	     * @return HTML
	     */
	    public function render_content()
	    {
	        if(!empty($this->fonts))
	        {
	            ?>
	                <label>
	                    <span class="customize-category-select-control" style="font-weight: bold; display: block; padding: 5px 0px;"><?php echo esc_html( $this->label ); ?><br /></span>
	                    
	                    <select <?php $this->link(); ?>>
	                        <?php
	                            foreach ( $this->fonts as $k => $v )
	                            {
	                               printf('<option value="%s" %s>%s</option>', $v->family, selected($this->value(), $k, false), $v->family);
	                            }
	                        ?>
	                    </select>
	                </label>
	            <?php
	        }
	    }
	
	    /**
	     * Get the google fonts from the API or in the cache
	     *
	     * @param  integer $amount
	     *
	     * @return String
	     */
	    public function get_fonts( $amount = 'all' )
	    {
	        $fontFile = get_template_directory().'/inc/cache/google-web-fonts.txt';
	
	        //Total time the file will be cached in seconds, set to a week
	        $cachetime = 86400 * 30;
	
	        if(file_exists($fontFile) && $cachetime < filemtime($fontFile))
	        {
	            $content = json_decode(file_get_contents($fontFile));
	           
	        } else {
	
	            $googleApi = 'https://www.googleapis.com/webfonts/v1/webfonts?sort=popularity&key=AIzaSyCnUNuE7iJyG-tuhk24EmaLZSC6yn3IjhQ';
	
	            $fontContent = wp_remote_get( $googleApi, array('sslverify'   => false) );
	
	            $fp = fopen($fontFile, 'w');
	            fwrite($fp, $fontContent['body']);
	            fclose($fp);
	
	            $content = json_decode($fontContent['body']);
	            
	        }
	
	        if($amount == 'all')
	        {
	            return $content->items;
	        } else {
	            return array_slice($content->items, 0, $amount);
	        }
	        
	    }
	 }
	
	
	
	$wp_customize->add_setting(
		'sixteen_title_font' ,array('default' => 'Roboto')
	);
	
	$wp_customize->add_control( new Google_Font_Dropdown_Custom_Control(
		$wp_customize,
		'sixteen_title_font',array(
				'label' => __('Title Font','sixteen'),
				'settings' => 'sixteen_title_font',
				'section'  => 'sixteen_typo_options',
			)
		)
	);
	
	
$wp_customize->add_setting(
		'sixteen_body_font',array('default' => 'Roboto')
	);
	
	$wp_customize->add_control(
		new Google_Font_Dropdown_Custom_Control(
		$wp_customize,
		'sixteen_body_font',array(
				'label' => __('Body Font','sixteen'),
				'settings' => 'sixteen_body_font',
				'section'  => 'sixteen_typo_options'
			)
		)	
	);

	
	// Social Icons
	$wp_customize->add_section('sixteen_social_section', array(
			'title' => __('Social Icons','sixteen'),
			'priority' => 44 ,
	));
	
	$social_networks = array( //Redefinied in Sanitization Function.
					'none' => __('-','protpress'),
					'facebook' => __('Facebook','sixteen'),
					'twitter' => __('Twitter','sixteen'),
					'google-plus' => __('Google Plus','sixteen'),
					'instagram' => __('Instagram','sixteen'),
					'rss' => __('RSS Feeds','sixteen'),
					'vine' => __('Vine','sixteen'),
					'vimeo' => __('Vimeo','sixteen'),
					'youtube' => __('Youtube','sixteen'),
					'flickr' => __('Flickr','sixteen'),
					'android' => __('Android','sixteen'),
					'apple' => __('Apple','sixteen'),
					'dribbble' => __('Dribbble','sixteen'),
					'foursquare' => __('FourSquare','sixteen'),
					'git' => __('Git','sixteen'),
					'linkedin' => __('Linked In','sixteen'),
					'paypal' => __('PayPal','sixteen'),
					'pinterest' => __('Pinterest','sixteen'),
					'reddit' => __('Reddit','sixteen'),
					'skype' => __('Skype','sixteen'),
					'soundcloud' => __('SoundCloud','sixteen'),
					'tumblr' => __('Tumblr','sixteen'),
					'windows' => __('Windows','sixteen'),
					'wordpress' => __('WordPress','sixteen'),
					'yelp' => __('Yelp','sixteen'),
					'vk' => __('VK.com','sixteen'),
				);
				
	$social_count = count($social_networks);
				
	for ($x = 1 ; $x <= 10 ; $x++) :
			
		$wp_customize->add_setting(
			'sixteen_social_'.$x, array(
				'sanitize_callback' => 'sixteen_sanitize_social',
				'default' => 'none'
			));

		$wp_customize->add_control( 'sixteen_social_'.$x, array(
					'settings' => 'sixteen_social_'.$x,
					'label' => __('Icon ','sixteen').$x,
					'section' => 'sixteen_social_section',
					'type' => 'select',
					'choices' => $social_networks,			
		));
		
		$wp_customize->add_setting(
			'sixteen_social_url'.$x, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'sixteen_social_url'.$x, array(
					'settings' => 'sixteen_social_url'.$x,
					'description' => __('Icon ','sixteen').$x.__(' Url','sixteen'),
					'section' => 'sixteen_social_section',
					'type' => 'url',
					'choices' => $social_networks,			
		));
		
	endfor;
	
	function sixteen_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook',
					'twitter',
					'google-plus',
					'instagram',
					'rss',
					'vine',
					'vimeo',
					'youtube',
					'flickr',
					'android',
					'apple',
					'dribbble',
					'foursquare',
					'git',
					'linkedin',
					'paypal',
					'pinterest',
					'reddit',
					'skype',
					'soundcloud',
					'tumblr',
					'windows',
					'wordpress',
					'yelp',
					'vk'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';	
	}
	
	// Advertisement
	
	class Sixteen_Custom_Ads_Control extends WP_Customize_Control {
	    public $type = 'textarea';
	 
	    public function render_content() {
	        ?>
	            <label>
	                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	                <span class="customize-control-description"><?php echo esc_html( $this->description ); ?></span>
	                <textarea rows="10" style="width:100%;" <?php $this->link(); ?>><?php echo $this->value(); ?></textarea>
	            </label>
	        <?php
	    }
	}
	
	$wp_customize->add_section('sixteen_ads', array(
			'title' => __('Advertisement','sixteen'),
			'priority' => 44 ,
	));
	
	$wp_customize->add_setting(
	'sixteen_topad',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sixteen_sanitize_ads'
		)
	);
	
	$wp_customize->add_control(
	    new Sixteen_Custom_Ads_Control(
	        $wp_customize,
	        'sixteen_topad',
	        array(
	            'section' => 'sixteen_ads',
	            'settings' => 'sixteen_topad',
	            'label'   => __('Above Content','sixteen'),
	            'description' => __('Enter your Responsive Adsense Code.','sixteen')
	        )
	    )
	);
	
	function sixteen_sanitize_ads( $input ) {
		  global $allowedposttags;
	      $custom_allowedtags["script"] = array();
	      $custom_allowedtags = array_merge($custom_allowedtags, $allowedposttags);
	      $output = wp_kses( $input, $custom_allowedtags);
	      return $output;
	}
	
	//Analytics
	$wp_customize-> add_section(
    'sixteen_analytics_js',
    array(
    	'title'			=> __('Google Analytics','sixteen'),
    	'description'	=> __('Enter your Analytics Code. It will be Included in Footer of the Site. Do NOT Include &lt;script&gt; and &lt;/script&gt; tags.','sixteen'),
    	'priority'		=> 45,
    	)
    );
    
	$wp_customize->add_setting(
	'sixteen_analytics',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sixteen_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
	    new Sixteen_Custom_JS_Control(
	        $wp_customize,
	        'sixteen_analytics',
	        array(
	            'section' => 'sixteen_analytics_js',
	            'settings' => 'sixteen_analytics'
	        )
	    )
	);
	
	
	/* Sanitization Functions Common to Multiple Settings go Here, Specific Sanitization Functions are defined along with add_setting() */
	function sixteen_sanitize_checkbox( $input ) {
	    if ( $input == 1 ) {
	        return 1;
	    } else {
	        return '';
	    }
	}
	
	function sixteen_sanitize_positive_number( $input ) {
		if ( ($input >= 0) && is_numeric($input) )
			return $input;
		else
			return '';	
	}
	
	function sixteen_sanitize_category( $input ) {
		if ( term_exists(get_cat_name( $input ), 'category') )
			return $input;
		else 
			return '';	
	}
	
	
}
add_action( 'customize_register', 'sixteen_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function sixteen_customize_preview_js() {
	wp_enqueue_script( 'sixteen_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'sixteen_customize_preview_js' );
